import QtQuick          2.3
import QtQuick.Controls 1.2
import QtQuick.Controls.Styles 1.4
import QtQuick.Dialogs  1.2
import QtQuick.Extras   1.4
import QtQuick.Layouts  1.2

import QGroundControl               1.0
import QGroundControl.ScreenTools   1.0
import QGroundControl.Vehicle       1.0
import QGroundControl.Controls      1.0
import QGroundControl.FactControls  1.0
import QGroundControl.Palette       1.0
import QGroundControl.FlightMap     1.0

// Editor for Operating Area items
Rectangle {
    id:         _root
    height:     visible ? (editorColumn.height + (_margin * 2)) : 0
    width:      availableWidth
    color:      qgcPal.windowShadeDark
    radius:     _radius

    // The following properties must be available up the hierarchy chain
    //property real   availableWidth    ///< Width for control
    //property var    areaItem       ///< Mission Item for editor

    property real   _margin:                    ScreenTools.defaultFontPixelWidth / 2
    property real   _fieldWidth:                ScreenTools.defaultFontPixelWidth * 10.5
    property var    polyline:                   areaItem.polyline
    property var    operatingPolygon:           areaItem
    property bool   initNecesarry:              true

    function editPolyline(){
        polyline.interactive = true;
    }




    QGCPalette { id: qgcPal; colorGroupEnabled: true }

    Column {
        id:                 editorColumn
        anchors.margins:    _margin
        anchors.top:        parent.top
        anchors.left:       parent.left
        anchors.right:      parent.right
        spacing:            _margin

        SectionHeader {
            id:         scanHeader
            text:       qsTr("Settings")
        }

        Column {
            anchors.left:   parent.left
            anchors.right:  parent.rightsetI
            spacing:        _margin
            visible:        scanHeader.checked

            GridLayout {
                anchors.left:   parent.left
                anchors.right:  parent.right
                columnSpacing:  _margin
                rowSpacing:     _margin
                columns:        2

                QGCLabel {
                    text:       qsTr("Bottom Layer Altitude")
                }
                FactTextField {
                    fact:               areaItem.bottomLayerAltitude
                    Layout.fillWidth:   true
                }

                /*QGCLabel { text: qsTr("Number of Layers") }
                FactTextField {
                    fact:               areaItem.numberOfLayers
                    Layout.fillWidth:   true
                }

                QGCLabel { text: qsTr("Layer Distance") }
                FactTextField {
                    fact:               areaItem.layerDistance
                    Layout.fillWidth:   true
                }*/


            }

            Item {
                height: ScreenTools.defaultFontPixelHeight / 2
                width:  1
            }
        } // Column - Scan
        SectionHeader {
            id:         polylineHeader
            text:       qsTr("Gateway Poly Line")
        }

        QGCButton {
            id:                     polylineEditor
            anchors.topMargin:      _margin / 2
            anchors.leftMargin:     ScreenTools.defaultFontPixelWidth * 2
            anchors.rightMargin:    ScreenTools.defaultFontPixelWidth
            text:                   "Edit Polyline"

            onClicked: editPolyline()
        }

        SectionHeader {
            id:     statsHeader
            text:   qsTr("Statistics")
        }

        Grid {
            columns:        2
            columnSpacing:  ScreenTools.defaultFontPixelWidth
            visible:        statsHeader.checked

            /*QGCLabel { text: qsTr("Layers") }
            QGCLabel { text: areaItem.layers.valueString }*/

            }
    } // Column
} // Rectangle
